@@ -6,7 +6,7 @@ from audible.activation_bytes import (
     fetch_activation_sign_auth
 )
 
-from ..config import pass_session
+from ..decorators import pass_session
 
 
 logger = logging.getLogger("audible_cli.cmds.cmd_activation_bytes")
